@@ -72,11 +72,8 @@ class TestInsertionCore():
         # the Geometry type's bind_processor and bind_expression functions.
         conn.execute(Lake.__table__.insert(), [
             {'geom': 'SRID=4326;LINESTRING(0 0,1 1)'},
-            {'geom': WKTElement('LINESTRING(0 0,2 2)', srid=4326)}
-
-            # Having WKBElement objects as bind values is not supported, so
-            # the following does not work:
-            # {'geom': from_shape(LineString([[0, 0], [3, 3]], srid=4326)}
+            {'geom': WKTElement('LINESTRING(0 0,2 2)', srid=4326)},
+            {'geom': from_shape(LineString([[0, 0], [3, 3]]), srid=4326)}
         ])
 
         results = conn.execute(Lake.__table__.select())
@@ -96,6 +93,13 @@ class TestInsertionCore():
         srid = session.execute(row[1].ST_SRID()).scalar()
         assert srid == 4326
 
+        row = rows[2]
+        assert isinstance(row[1], WKBElement)
+        wkt = session.execute(row[1].ST_AsText()).scalar()
+        assert wkt == 'LINESTRING(0 0, 3 3)'
+        srid = session.execute(row[1].ST_SRID()).scalar()
+        assert srid == 4326
+
 
 class TestInsertionORM():
 
