@@ -18,12 +18,6 @@ def geometry_table():
     return table
 
 
-@pytest.fixture
-def geometry_table_no_st_prefix():
-    table = Table('table', MetaData(), Column('geom', Geometry(use_st_prefix=False)))
-    return table
-
-
 @pytest.fixture
 def geography_table():
     table = Table('table', MetaData(), Column('geom', Geography))
@@ -50,6 +44,38 @@ class TestGeometry():
         with pytest.raises(ArgumentError):
             Geometry(srid='foo')
 
+    def test_get_col_spec_dimension4D(self):
+        g = Geometry(geometry_type='GEOMETRYZM', srid=900913, dimension=4)
+        assert g.get_col_spec() == 'geometry(GEOMETRYZM,900913)'
+
+    def test_get_col_spec_dimension3DZ(self):
+        g = Geometry(geometry_type='GEOMETRYZ', srid=900913, dimension=3)
+        assert g.get_col_spec() == 'geometry(GEOMETRYZ,900913)'
+
+    def test_get_col_spec_dimension3DM(self):
+        g = Geometry(geometry_type='GEOMETRYM', srid=900913, dimension=3)
+        assert g.get_col_spec() == 'geometry(GEOMETRYM,900913)'
+
+    def test_check_ctor_args_bad_geometry_type_dimension4D(self):
+        with pytest.raises(ArgumentError):
+            Geometry(geometry_type='GEOMETRY', dimension=4)
+
+    def test_check_ctor_args_bad_geometry_type_Z_dimension4D(self):
+        with pytest.raises(ArgumentError):
+            Geometry(geometry_type='GEOMETRYZ', dimension=4)
+
+    def test_check_ctor_args_bad_geometry_type_M_dimension4D(self):
+        with pytest.raises(ArgumentError):
+            Geometry(geometry_type='GEOMETRYM', dimension=4)
+
+    def test_check_ctor_args_bad_geometry_type_dimension3D(self):
+        with pytest.raises(ArgumentError):
+            Geometry(geometry_type='GEOMETRY', dimension=3)
+
+    def test_check_ctor_args_bad_geometry_type_ZM_dimension3D(self):
+        with pytest.raises(ArgumentError):
+            Geometry(geometry_type='GEOMETRYZM', dimension=3)
+
     def test_check_ctor_args_incompatible_arguments(self):
         with pytest.raises(ArgumentError):
             Geometry(geometry_type=None, management=True)
@@ -66,45 +92,23 @@ class TestGeometry():
         s = select([geometry_table.c.geom])
         eq_sql(s, 'SELECT ST_AsEWKB("table".geom) AS geom FROM "table"')
 
-    def test_column_expression_no_st_prefix(self, geometry_table_no_st_prefix):
-        s = select([geometry_table_no_st_prefix.c.geom])
-        eq_sql(s, 'SELECT AsEWKB("table".geom) AS geom FROM "table"')
-
     def test_select_bind_expression(self, geometry_table):
         s = select([text('foo')]).where(geometry_table.c.geom == 'POINT(1 2)')
         eq_sql(s, 'SELECT foo FROM "table" WHERE '
                   '"table".geom = ST_GeomFromEWKT(:geom_1)')
         assert s.compile().params == {'geom_1': 'POINT(1 2)'}
 
-    def test_select_bind_expression_no_st_prefix(self, geometry_table_no_st_prefix):
-        s = select([text('foo')]).where(geometry_table_no_st_prefix.c.geom == 'POINT(1 2)')
-        eq_sql(s, 'SELECT foo FROM "table" WHERE '
-                  '"table".geom = GeomFromEWKT(:geom_1)')
-        assert s.compile().params == {'geom_1': 'POINT(1 2)'}
-
     def test_insert_bind_expression(self, geometry_table):
         i = insert(geometry_table).values(geom='POINT(1 2)')
         eq_sql(i, 'INSERT INTO "table" (geom) VALUES (ST_GeomFromEWKT(:geom))')
         assert i.compile().params == {'geom': 'POINT(1 2)'}
 
-    def test_insert_bind_expression_no_st_prefix(self, geometry_table_no_st_prefix):
-        i = insert(geometry_table_no_st_prefix).values(geom='POINT(1 2)')
-        eq_sql(i, 'INSERT INTO "table" (geom) VALUES (GeomFromEWKT(:geom))')
-        assert i.compile().params == {'geom': 'POINT(1 2)'}
-
     def test_function_call(self, geometry_table):
         s = select([geometry_table.c.geom.ST_Buffer(2)])
         eq_sql(s,
                'SELECT ST_AsEWKB(ST_Buffer("table".geom, :ST_Buffer_2)) '
                'AS "ST_Buffer_1" FROM "table"')
 
-    def test_function_call_no_st_prefix(self, geometry_table):
-        type_ = Geometry(use_st_prefix=False)
-        s = select([geometry_table.c.geom.ST_Buffer(2, type_=type_)])
-        eq_sql(s,
-               'SELECT AsEWKB(ST_Buffer("table".geom, :ST_Buffer_2)) '
-               'AS "ST_Buffer_1" FROM "table"')
-
     def test_non_ST_function_call(self, geometry_table):
         with pytest.raises(AttributeError):
             geometry_table.c.geom.Buffer(2)
